#[non_exhaustive]pub enum Scent {
Char(char),
Range(char, char),
Union(MultipleOdors),
Repetition(Odor),
Marked(Odor),
}Expand description
The atomic element of a unicode string pattern.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Char(char)
Matches the given char.
Range(char, char)
Matches a single char whose code point is within the inclusive range of the 2 given.
Union(MultipleOdors)
Matches any of the given Odors.
Matches are attempted in the given order.
Repetition(Odor)
Matches any number of repetitions of the given Odor.
Matches are attempted starting with 0 repetitions (an empty string) and incrementing the number of repetitions by 1 until a match cannot be made.
Marked(Odor)